@@ -1,7 +1,7 @@
 // qsynthMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -65,7 +65,7 @@ const WindowFlags CustomizeWindowHint   = WindowFlags(0x02000000);
 
 // Timer constant stuff.
 #define QSYNTH_TIMER_MSECS  100
-#define QSYNTH_DELAY_MSECS  200
+#define QSYNTH_DELAY_MSECS  300
 
 // Scale factors.
 #define QSYNTH_MASTER_GAIN_SCALE    100.0f
@@ -802,7 +802,8 @@ void qsynthMainForm::dragEnterEvent ( QDragEnterEvent* pDragEnterEvent )
 				const QString& sFilename
 					= iter.next().toLocalFile();
 				if (!sFilename.isEmpty()) {
-					char *pszFilename = sFilename.toLocal8Bit().data();
+                                        QByteArray tmp = sFilename.toLocal8Bit();
+					char *pszFilename = tmp.data();
 					if (::fluid_is_midifile(pszFilename) ||
 						::fluid_is_soundfont(pszFilename))
 						bAccept = true;
@@ -2493,4 +2494,16 @@ void qsynthMainForm::updateKnobs()
 }
 
 
+// Session (desktop) shutdown signal handler.
+void qsynthMainForm::setQuitForce ( bool bQuitForce )
+{
+	m_bQuitForce = bQuitForce;
+}
+
+bool qsynthMainForm::isQuitForce (void) const
+{
+	return m_bQuitForce;
+}
+
+
 // end of qsynthMainForm.cpp
