@@ -1,7 +1,7 @@
 // qsynthMainForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -72,6 +72,9 @@ public:
 
 	enum KnobStyle { Classic, Vokimon, Peppino, Skulpture, Legacy };
 
+	void setQuitForce(bool bQuitForce);
+	bool isQuitForce() const;
+
 public slots:
 
 	void stdoutNotifySlot(int);
