@@ -1,7 +1,7 @@
 // qsynthOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -278,7 +278,7 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			if (sVal.isEmpty()) {
 				out << QObject::tr("Option -G requires an argument (audio-groups).") + sEol;
 				return false;
-		}
+			}
 			m_pDefaultSetup->iAudioGroups = sVal.toInt();
 			if (iEqual < 0)
 				i++;
@@ -366,11 +366,12 @@ bool qsynthOptions::parse_args ( const QStringList& args )
 			return false;
 		}
 		else {
-			char *name = args.at(i).toUtf8().data();
+			QByteArray tmp = args.at(i).toUtf8();
+			char *name = tmp.data();
 			if (::fluid_is_soundfont(name)) {
 				if (++iSoundFontOverride == 1) {
-					m_pDefaultSetup->soundfonts.clear();
-					m_pDefaultSetup->bankoffsets.clear();
+						m_pDefaultSetup->soundfonts.clear();
+						m_pDefaultSetup->bankoffsets.clear();
 				}
 				m_pDefaultSetup->soundfonts.append(name);
 				m_pDefaultSetup->bankoffsets.append(QString::null);
@@ -472,19 +473,19 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 	pSetup->bMidiIn          = m_settings.value("/MidiIn", true).toBool();
 #if defined(WIN32)
 	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "winmidi").toString();
-    pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "dsound").toString();
-    pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 512).toInt();
-    pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 8).toInt();
+	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "dsound").toString();
+	pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 512).toInt();
+	pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 8).toInt();
 #else
 	pSetup->sMidiDriver      = m_settings.value("/MidiDriver", "alsa_seq").toString();
-    pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "jack").toString();
-    pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 64).toInt();
-    pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 2).toInt();
+	pSetup->sAudioDriver     = m_settings.value("/AudioDriver", "jack").toString();
+	pSetup->iAudioBufSize    = m_settings.value("/AudioBufSize", 64).toInt();
+	pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 2).toInt();
 #endif
-    pSetup->sAlsaName        = m_settings.value("/AlsaName", "pid").toString();
-    pSetup->sJackName        = m_settings.value("/JackName", "qsynth").toString();
-    pSetup->bJackAutoConnect = m_settings.value("/JackAutoConnect", true).toBool();
-    pSetup->bJackMulti       = m_settings.value("/JackMulti", false).toBool();
+	pSetup->sMidiName        = m_settings.value("/AlsaName", "pid").toString();
+	pSetup->sJackName        = m_settings.value("/JackName", "qsynth").toString();
+	pSetup->bJackAutoConnect = m_settings.value("/JackAutoConnect", true).toBool();
+	pSetup->bJackMulti       = m_settings.value("/JackMulti", false).toBool();
 	pSetup->sMidiDevice      = m_settings.value("/MidiDevice").toString();
 	pSetup->iMidiChannels    = m_settings.value("/MidiChannels", 16).toInt();
 	pSetup->sAudioDevice     = m_settings.value("/AudioDevice").toString();
@@ -521,7 +522,7 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 		QString sSoundFont  = m_settings.value(sSoundFontPrefix.arg(i)).toString();
 		QString sBankOffset = m_settings.value(sBankOffsetPrefix.arg(i)).toString();
 		if (sSoundFont.isEmpty())
-			break;
+				break;
 		pSetup->soundfonts.append(sSoundFont);
 		pSetup->bankoffsets.append(sBankOffset);
 	}
@@ -583,7 +584,7 @@ void qsynthOptions::saveSetup ( qsynthSetup *pSetup, const QString& sName )
 	// Cleanup old entries, if any...
 	for (;;) {
 		if (m_settings.value(sSoundFontPrefix.arg(++i)).toString().isEmpty())
-			break;
+				break;
 		m_settings.remove(sSoundFontPrefix.arg(i));
 		m_settings.remove(sBankOffsetPrefix.arg(i));
 	}
@@ -596,7 +597,7 @@ void qsynthOptions::saveSetup ( qsynthSetup *pSetup, const QString& sName )
 	m_settings.setValue("/MidiDriver",       pSetup->sMidiDriver);
 	m_settings.setValue("/MidiDevice",       pSetup->sMidiDevice);
 	m_settings.setValue("/MidiChannels",     pSetup->iMidiChannels);
-	m_settings.setValue("/AlsaName",         pSetup->sAlsaName);
+	m_settings.setValue("/AlsaName",         pSetup->sMidiName);
 	m_settings.setValue("/AudioDriver",      pSetup->sAudioDriver);
 	m_settings.setValue("/AudioDevice",      pSetup->sAudioDevice);
 	m_settings.setValue("/JackName",         pSetup->sJackName);
@@ -650,7 +651,7 @@ bool qsynthOptions::loadPreset ( qsynthEngine *pEngine, const QString& sPreset )
 		sSuffix = '/' + sPreset;
 		// Check if on list.
 		if (!pSetup->presets.contains(sPreset))
-			return false;
+				return false;
 	}
 
 	// Begin at key group?
@@ -658,6 +659,9 @@ bool qsynthOptions::loadPreset ( qsynthEngine *pEngine, const QString& sPreset )
 		m_settings.beginGroup("/Engine/" + pEngine->name());
 
 	// Load as current presets.
+#ifdef CONFIG_FLUID_UNSET_PROGRAM
+	int iChannelsSet = 0;
+#endif
 	const QString sPrefix = "/Chan%1";
 	m_settings.beginGroup("/Preset" + sSuffix);
 	int iChannels = ::fluid_synth_count_midi_channels(pEngine->pSynth);
@@ -668,6 +672,9 @@ bool qsynthOptions::loadPreset ( qsynthEngine *pEngine, const QString& sPreset )
 				sEntry.section(':', 1, 1).toInt());
 			::fluid_synth_program_change(pEngine->pSynth, iChan,
 				sEntry.section(':', 2, 2).toInt());
+		#ifdef CONFIG_FLUID_UNSET_PROGRAM
+			++iChannelsSet;
+		#endif
 		}
 	#ifdef CONFIG_FLUID_UNSET_PROGRAM
 		else ::fluid_synth_unset_program(pEngine->pSynth, iChan);
@@ -679,6 +686,20 @@ bool qsynthOptions::loadPreset ( qsynthEngine *pEngine, const QString& sPreset )
 	if (!pEngine->isDefault())
 		m_settings.endGroup();
 
+#ifdef CONFIG_FLUID_UNSET_PROGRAM
+	// If there's none channels set (eg. empty/blank preset)
+	// then fallback to old default fill up all the channels
+	// according to available soundfont stack.
+	if (iChannelsSet < 1) {
+		int iProg = 0;
+		for (int iChan = 0; iChan < iChannels; iChan++) {
+			::fluid_synth_bank_select(pEngine->pSynth, iChan, 0);
+			::fluid_synth_program_change(pEngine->pSynth, iChan, iProg);
+			++iProg;
+		}
+	}
+#endif
+	
 	// Recommended to post-stabilize things around.
 	::fluid_synth_program_reset(pEngine->pSynth);
 
@@ -699,7 +720,7 @@ bool qsynthOptions::savePreset ( qsynthEngine *pEngine, const QString& sPreset )
 		sSuffix = '/' + sPreset;
 		// Append to list if not already.
 		if (!pSetup->presets.contains(sPreset))
-			pSetup->presets.prepend(sPreset);
+				pSetup->presets.prepend(sPreset);
 	}
 
 	// Begin at key group?
@@ -773,7 +794,7 @@ bool qsynthOptions::deletePreset ( qsynthEngine *pEngine, const QString& sPreset
 		sSuffix = "/" + sPreset;
 		int iPreset = pSetup->presets.indexOf(sPreset);
 		if (iPreset < 0)
-			return false;
+				return false;
 		pSetup->presets.removeAt(iPreset);
 		m_settings.remove(sPrefix + "/Preset" + sSuffix);
 	}
@@ -874,16 +895,16 @@ void qsynthOptions::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	// (due to X11 window managers ideossincrasies, we better
 	// only save the form geometry while its up and visible)
 	if (pWidget) {
-		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-		const QPoint& wpos  = pWidget->pos();
-		const QSize&  wsize = pWidget->size();
-		if (!bVisible) bVisible = pWidget->isVisible();
-		m_settings.setValue("/x", wpos.x());
-		m_settings.setValue("/y", wpos.y());
-		m_settings.setValue("/width", wsize.width());
-		m_settings.setValue("/height", wsize.height());
-		m_settings.setValue("/visible", bVisible && !bStartMinimized);
-		m_settings.endGroup();
+			m_settings.beginGroup("/Geometry/" + pWidget->objectName());
+			const QPoint& wpos  = pWidget->pos();
+			const QSize&  wsize = pWidget->size();
+			if (!bVisible) bVisible = pWidget->isVisible();
+			m_settings.setValue("/x", wpos.x());
+			m_settings.setValue("/y", wpos.y());
+			m_settings.setValue("/width", wsize.width());
+			m_settings.setValue("/height", wsize.height());
+			m_settings.setValue("/visible", bVisible && !bStartMinimized);
+			m_settings.endGroup();
 	}
 }
 
