@@ -1,7 +1,7 @@
 // qsynthPresetForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
 #include "qsynthOptions.h"
 
 #include <QHeaderView>
+#include <QPushButton>
 #include <QFileInfo>
 
 
@@ -104,14 +105,17 @@ qsynthPresetForm::qsynthPresetForm (
 	QObject::connect(m_ui.PreviewCheckBox,
 		SIGNAL(toggled(bool)),
 		SLOT(previewChanged()));
+//	QObject::connect(m_ui.ProgListView,
+//		SIGNAL(itemActivated(QTreeWidgetItem*,int)),
+//		SLOT(accept()));
 	QObject::connect(m_ui.ProgListView,
-		SIGNAL(itemActivated(QTreeWidgetItem*,int)),
+		SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
 		SLOT(accept()));
-	QObject::connect(m_ui.OkPushButton,
-		SIGNAL(clicked()),
+	QObject::connect(m_ui.DialogButtonBox,
+		SIGNAL(accepted()),
 		SLOT(accept()));
-	QObject::connect(m_ui.CancelPushButton,
-		SIGNAL(clicked()),
+	QObject::connect(m_ui.DialogButtonBox,
+		SIGNAL(rejected()),
 		SLOT(reject()));
 }
 
@@ -219,7 +223,8 @@ void qsynthPresetForm::setup ( qsynthOptions *pOptions, fluid_synth_t *pSynth, i
 // Stabilize current state form.
 void qsynthPresetForm::stabilizeForm()
 {
-	m_ui.OkPushButton->setEnabled(validateForm());
+	m_ui.DialogButtonBox->button(
+		QDialogButtonBox::Ok)->setEnabled(validateForm());
 }
 
 
