@@ -1,7 +1,7 @@
 // qsynthSystemTray.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,6 +25,16 @@
 #include <QBitmap>
 #include <QPainter>
 
+#if QT_VERSION < 0x040500
+namespace Qt {
+const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
+#if QT_VERSION < 0x040200
+const WindowFlags CustomizeWindowHint   = WindowFlags(0x02000000);
+#endif
+}
+#endif
+
+
 #ifndef QSYNTH_QT4_SYSTEM_TRAY
 
 #include <QMouseEvent>
@@ -103,9 +113,7 @@ void qsynthSystemTray::activated ( QSystemTrayIcon::ActivationReason reason )
 // Constructor.
 qsynthSystemTray::qsynthSystemTray ( QWidget *pParent )
 	: QWidget(pParent, Qt::Window
-#if QT_VERSION >= 0x040200
 		| Qt::CustomizeWindowHint
-#endif
 		| Qt::X11BypassWindowManagerHint
 		| Qt::FramelessWindowHint
 		| Qt::WindowStaysOnTopHint)
